@@ -2,6 +2,7 @@ from argparse import ArgumentParser, RawTextHelpFormatter
 import os
 from pathlib import Path
 import subprocess
+import sys
 
 from ffmpeg import probe
 from tqdm import tqdm
@@ -9,7 +10,7 @@ from .utils import FileInfoProvider
 
 
 class FfmpegProcess:
-    def __init__(self, command, ffmpeg_loglevel="verbose"):
+    def __init__(self, command, ffmpeg_loglevel="panic"):
         """
         Creates the list of FFmpeg arguments.
         Accepts an optional ffmpeg_loglevel parameter to set the value of FFmpeg's -loglevel argument.
@@ -51,7 +52,6 @@ class FfmpegProcess:
         ffmpeg_stderr = ""
 
         print("Running FFmpeg...")
-        print('bla')
 
         with open(ffmpeg_output_file, "a") as f:
             self._process = subprocess.Popen(
